@@ -7,9 +7,9 @@
 #
 ##-----------------------------------------------------------------------------
 softTh <- function(y, thld) {
-    x <- abs(y);
-    x <- sign(y) * (x >= thld) * (x - thld); 
+    x <- abs(y)
+    x <- sign(y) * (x >= thld) * (x - thld)
 
-    return(x);
+    return(x)
 }
 
