@@ -4,15 +4,14 @@
 
 library(rwt)
 
-test.daubcqf <- function(len, type, expected) {
-   result <- daubcqf(len, type);
+test.daubcqf <- function(input, expected) {
+   result <- daubcqf(input$N, input$type)
    identical(all.equal(result,
                        expected,
                        tolerance = 0.0000001),
-             TRUE);
+             TRUE)
 }
 
-N <- 4;
 daubcqf.expected <- list(h.0 = c( 0.4829629,
                                   0.8365163,
                                   0.2241439,
@@ -20,7 +19,7 @@ daubcqf.expected <- list(h.0 = c( 0.4829629,
                          h.1 = c( 0.1294095,
                                   0.2241439,
                                  -0.8365163,
-                                  0.4829629));
+                                  0.4829629))
 
-test.daubcqf(N, PHASE.MINIMUM, daubcqf.expected);
+test.daubcqf(list(N = 4, type = PHASE.MINIMUM), daubcqf.expected)
 
