@@ -4,16 +4,15 @@
 
 library(rwt)
 
-test.hardTh <- function(signal, thld, expected) {
-   result <- rwt::hardTh(signal, thld);
+test.hardTh <- function(input, expected) {
+   result <- rwt::hardTh(input$signal, input$thld)
    identical(all.equal(as.vector(result),
                        expected,
                        tolerance = 0.000001),
-             TRUE);
+             TRUE)
 }
 
-y <- makesig(SIGNAL.WERNER.SORROWS, 8);
-thld <- 1;
+sig <- rwt::makesig(SIGNAL.WERNER.SORROWS, 8)
 hardTh.expected <- c( 1.554523,
                       5.317538,
                       0.0,
@@ -21,7 +20,7 @@ hardTh.expected <- c( 1.554523,
                      -1.267779,
                       0.0,
                       1.733160,
-                      0.0);
+                      0.0)
 
-test.hardTh(y$x, thld, hardTh.expected);
+test.hardTh(list(signal = sig$x, thld = 1), hardTh.expected)
 
