@@ -4,21 +4,19 @@
 
 library(rwt)
 
-test.midwt <- function(signal, filter, nlevels, expected) {
-   ret.mdwt <- mdwt(signal, filter, nlevels);
+test.midwt <- function(input, expected) {
+   ret.mdwt <- rwt::mdwt(input$signal, input$filter, input$nlevels)
    y <- ret.mdwt$y
    L <- ret.mdwt$L
-   result <- midwt(y, filter, L);
+   result <- rwt::midwt(y, input$filter, L)
    identical(all.equal(result,
                        expected,
                        tolerance = 0.000001),
-             TRUE);
+             TRUE)
 }
 
-sig <- makesig(SIGNAL.LIN.CHIRP, 8);
-h <- daubcqf(4, PHASE.MINIMUM);
-L <- 1;
-
+sig <- rwt::makesig(SIGNAL.LIN.CHIRP, 8)
+h <- rwt::daubcqf(4, PHASE.MINIMUM)
 midwt.expected <- list(x = matrix(data = c( 0.04906767,
                                             0.1950903,
                                             0.4275551,
@@ -28,7 +26,7 @@ midwt.expected <- list(x = matrix(data = c( 0.04906767,
                                             0.671559,
                                             0.0000),
                                  nrow = 1),
-                      L = 1);
+                      L = 1)
 
-test.midwt(sig$x, h$h.0, L, midwt.expected);
+test.midwt(list(signal = sig$x, filter = h$h.0, nlevels = 1), midwt.expected)
 
